# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`win_dns_server`](#win_dns_server): Configures the Windows DNS Server service on a given node.
* [`win_dns_server::config`](#win_dns_serverconfig): Performs zone creation and update operations. Internal class
* [`win_dns_server::install`](#win_dns_serverinstall): Adds the Windows DNS Server feature
* [`win_dns_server::service`](#win_dns_serverservice): Internal class which configures the DNS service

### Resource types

* [`conditional_forwarder_zone`](#conditional_forwarder_zone)

### Data types

* [`Win_dns_server::ConditionalForwarderZone`](#win_dns_serverconditionalforwarderzone): Parameters for the conditional_forwarder_zone type
* [`Win_dns_server::Settings`](#win_dns_serversettings): Global dns server settings

## Classes

### <a name="win_dns_server"></a>`win_dns_server`

Configures the Windows DNS Server service on a given node.

#### Parameters

The following parameters are available in the `win_dns_server` class:

* [`hash_server_settings`](#hash_server_settings)
* [`array_publish_addresses`](#array_publish_addresses)
* [`hash_forwarder_zones`](#hash_forwarder_zones)

##### <a name="hash_server_settings"></a>`hash_server_settings`

Data type: `Win_dns_server::Settings`

THis hash configures global DNS service settings when specified. These
settings are derived from the
[xDnsServer](https://github.com/puppetlabs/puppetlabs-dsc/blob/master/types.md#xdnsserver)
module

##### <a name="array_publish_addresses"></a>`array_publish_addresses`

Data type: `Optional[Array[Stdlib::IP::Address::V4::Nosubnet]]`

Optional array listing the addresses this DNS server should self publish. By
default the DNS server will publish only it's primary IP.

Default value: `[]`

##### <a name="hash_forwarder_zones"></a>`hash_forwarder_zones`

Data type: `Optional[Hash[Stdlib::Fqdn,Win_dns_server::ConditionalForwarderZone]]`

A hash detailing the conditional forwarding DNS zones which will be created
on this server. Note that the key to the hash is used as the zone name and
must be specified.

Default value: `{}`

### <a name="win_dns_serverconfig"></a>`win_dns_server::config`

Performs zone creation and update operations. Internal class

#### Parameters

The following parameters are available in the `win_dns_server::config` class:

* [`array_publish_addresses`](#array_publish_addresses)
* [`hash_server_settings`](#hash_server_settings)
* [`hash_forwarder_zones`](#hash_forwarder_zones)

##### <a name="array_publish_addresses"></a>`array_publish_addresses`

Data type: `Array[Stdlib::IP::Address::V4::Nosubnet]`

See main class documentation.

Default value: `$win_dns_server::array_publish_addresses`

##### <a name="hash_server_settings"></a>`hash_server_settings`

Data type: `Win_dns_server::Settings`



Default value: `$win_dns_server::hash_server_settings`

##### <a name="hash_forwarder_zones"></a>`hash_forwarder_zones`

Data type: `Hash[Stdlib::Fqdn,Win_dns_server::ConditionalForwarderZone]`



Default value: `$win_dns_server::hash_forwarder_zones`

### <a name="win_dns_serverinstall"></a>`win_dns_server::install`

Adds the Windows DNS Server feature

### <a name="win_dns_serverservice"></a>`win_dns_server::service`

Internal class which configures the DNS service

## Resource types

### <a name="conditional_forwarder_zone"></a>`conditional_forwarder_zone`

The conditional_forwarder_zone type.

#### Properties

The following properties are available in the `conditional_forwarder_zone` type.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this conditional forwarder zone should be presesnt or absent on the target node.

##### `forwarder_timeout`

Data type: `Integer[0,15]`

The the maximum amount of time, in seconds, that this server will wait for a response from one of the forwarder targets.

Default value: `3`

##### `master_servers`

Data type: `Array[Pattern[/\A([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])(\.([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])){3}\z/]]`
_*this data type contains a regex that may not be accurately reflected in generated documentation_

An array of servers which are authoratative for this DNS zone. These *must* be specificed by IP.

##### `use_recursion`

Data type: `Boolean`

When true the DNS server will perform recursive queries to resolve names in this zone if it does not receive a response before the forward timeout.

Default value: `false`

#### Parameters

The following parameters are available in the `conditional_forwarder_zone` type.

* [`name`](#name)

##### <a name="name"></a>`name`

namevar

Data type: `Pattern[/\A(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])\z/]`
_*this data type contains a regex that may not be accurately reflected in generated documentation_

The fully qualified DNS zone name. This includes both forward lookup zones like 'example.org' and reverse lookup zones
like '48.0.10.in-addr.arpa'

## Data types

### <a name="win_dns_serverconditionalforwarderzone"></a>`Win_dns_server::ConditionalForwarderZone`

Parameters for the conditional_forwarder_zone type

Alias of

```puppet
Struct[=>]
```

### <a name="win_dns_serversettings"></a>`Win_dns_server::Settings`

Global dns server settings

Alias of

```puppet
Struct[=>]
```

